export declare type AuthInfo = {
    userId: number;
    tenantId: number;
};
export declare type ScreenLayerId = number | string;
export interface ScreenLayerItem {
    id: ScreenLayerId;
    name: string;
    show: boolean;
    lock: boolean;
    moduleName?: string;
    collapsed?: boolean;
    components?: ScreenLayerItem[] | Partial<ScreenLayerItem>[];
    remove_it?: boolean;
    hideDefault?: boolean;
    mountAnimation?: any;
    transform?: any;
    movable?: boolean;
    topKey?: string;
    leftKey?: string;
    leftOffset?: string;
    topOffset?: string;
    transitionTime?: number;
}
export declare type Optional<T, K extends keyof T> = Partial<T> & Pick<T, K>;
export declare enum DataType {
    STATIC = "static",
    API = "api",
    MYSQL = "mysql",
    CSV = "csv",
    ORACLE = "oracle",
    MSSQL = "mssql",
    APIGATEWAY = "apiGateway",
    POSTGRESQL = "postgresql",
    CLICKHOUSE = "clickhouse",
    DTINSIGHT = "dtInsight"
}
export declare type ComponentStaticData = {
    data: any[] | null;
    fields: any[] | null;
};
export interface ComponentDataConfigConfig {
    data: {
        [propName: string]: any;
        data_id: string;
    };
    fields: any;
}
export interface ComponentFilter {
    id: number;
    enable: boolean;
}
export interface APIGatewayConfig {
    data_id: string;
    method: "get" | "post";
    path?: string;
    params?: string;
    body?: string;
    headers?: string;
}
export interface DTInsightConfig {
    data_id: string;
    method: "get" | "post";
    path?: string;
    params?: string;
    body?: string;
    headers?: string;
}
export declare type ApiMethod = "get" | "post" | "put" | "patch" | "delete";
export interface APIConfig {
    data_id?: string;
    method?: ApiMethod;
    path?: string;
    params?: string;
    needCookie?: boolean;
    body?: string;
    headers?: string;
    reqFromBack?: boolean;
}
export declare type CompoenntDataConfigFields = {
    name: string;
    value: string;
    desc: string;
}[];
export interface ComponentDataConfig {
    type?: DataType;
    [DataType.API]?: {
        data: APIConfig;
        fields: CompoenntDataConfigFields;
    };
    [DataType.CSV]?: ComponentDataConfigConfig;
    [DataType.APIGATEWAY]?: {
        data: APIGatewayConfig;
        fields: CompoenntDataConfigFields;
    };
    [DataType.MSSQL]?: ComponentDataConfigConfig;
    [DataType.MYSQL]?: ComponentDataConfigConfig;
    [DataType.ORACLE]?: ComponentDataConfigConfig;
    [DataType.POSTGRESQL]?: ComponentDataConfigConfig;
    [proName: string]: any;
}
export * from "./filter";
